package com.topcoder.web.urlhistory;

import java.util.Date;
import java.util.List;
import java.util.Set;

import com.topcoder.user.profile.UserProfile;
import com.topcoder.web.urlhistory.compare.IPAddressComparator;
import com.topcoder.web.urlhistory.compare.PartialComparator;
import com.topcoder.web.urlhistory.data.Flag;
import com.topcoder.web.urlhistory.data.GroupInfo;
import com.topcoder.web.urlhistory.data.GroupStatistics;
import com.topcoder.web.urlhistory.data.URLInfo;
import com.topcoder.web.urlhistory.data.URLStatistics;
import com.topcoder.web.urlhistory.data.UserInfo;
import com.topcoder.web.urlhistory.persistence.DatabasePersistence;
import com.topcoder.web.urlhistory.sort.LastVisitSort;

/**
 * Demo
 */
public class Demo {
    
    private UserProfile userProfile;
    
    public Demo() throws Exception {
        
// get managers
GeneralManager man = GeneralManager.getInstance();
UserManager um = man.getUserManager();
GroupManager gm = man.getGroupManager();
URLManager urlm = man.getURLManager();
StatisticsManager sm = man.getStatisticsManager();                

// create user with expiration option
UserInfo user = new UserInfo();
user.setAttribute(DatabasePersistence.EXPIRATION_AGE_KEY, "10");        
um.createUser(userProfile, user);

// change user
user.setAttribute(DatabasePersistence.EXPIRATION_AGE_KEY, "5");
um.updateUser(user);

// remove user
um.removeUser(user);

// clear all users
um.clearUsers();

// get user by user profile
user = um.getUser(userProfile);

// get all users
Set users = um.getAllUsers();

// create group and subgroup
GroupInfo gr1 = new GroupInfo("gr1");
gm.createGroup(userProfile, gr1);
gm.createGroup(new GroupInfo("gr2"), gr1);

// update group by blacklisting it and changing name
gr1.setName("gr11");
gr1.setBlackListed(Flag.YES);
gm.updateGroup(gr1);

// remove group
gm.removeGroup(gr1);

// clear subgroups of gr1 and all root groups 
gm.clearSubgroups(gr1);
gm.clearSubgroups(null);

// get group by id, get subgroups and get parent group
gr1 = gm.getGroup(1000);
gr1 = gm.getParentGroup(gr1);
Set groups = gm.getSubgroups(gr1);

// create URL
URLInfo urlInfo1 = new URLInfo("yahoo", "http://mail.yahoo.com/");
urlm.createURL(userProfile, urlInfo1);

// update URL and set flags
urlInfo1.setName("yahoo mail");
urlInfo1.setBlackListed(Flag.NO);
urlInfo1.setNeverExpire(Flag.YES);
urlm.updateURL(urlInfo1);

// remove URL
urlm.removeURL(urlInfo1);

// clear all URLs belonging to gr1
urlm.clearURLs(gr1);

// get URLs by id, by user profile and URL string
// and get all URLs from a group
urlInfo1 = urlm.getURL(1000);
urlInfo1 = urlm.getURL(userProfile, "http://mail.yahoo.com/");
Set urls = urlm.getURLs(gr1);

// different way to blacklist and set never expired
// can be used to bulk blacklist for example is the comparator is
// very relaxed (many URLs are considered the same)
urlm.setBlackListed(userProfile, "10.0.0.1", new IPAddressComparator(), Flag.YES);
urlm.setNeverExpire(userProfile, "http://www.topcoder.com/", new PartialComparator(0, false), Flag.YES);

// visit URL
sm.visit(urlInfo1, new Date());
sm.visit(userProfile, "http://mail.yahoo.com/", new Date());

// get report for one specific URL
URLStatistics stat = sm.getVisitStatistics(urlInfo1);
System.out.println(stat.getVisitCount());        
System.out.println(stat.getLastVisit());        
System.out.println(stat.getPersonalRating());

// get report for a URL but with given comparator
stat = sm.getVisitStatistics(userProfile, "http://mail.yahoo.com/", new IPAddressComparator());
System.out.println(stat.getVisitCount());        
System.out.println(stat.getLastVisit());        
System.out.println(stat.getPersonalRating());

// sort URLs by last visit using partial level comparator
List list = sm.sortURLs(userProfile, new LastVisitSort(), new PartialComparator(3, true));
System.out.println(((URLStatistics) list.get(0)).getVisitCount());

// sort groups by last visit and display aggregated visit count
// of all URLs belonging to it
list = sm.sortGroups(userProfile, new LastVisitSort());
System.out.println(((GroupStatistics) list.get(0)).getVisitCount());
        
    }

}
