package com.topcoder.web.urlhistory.data;

import java.util.Date;

/**
 * The GroupStatistics class is used to return to the user statistical information
 * about groups.
 * 
 * Group statistics store the group name, visit count, last visit and personal rating.
 * Note that group statistics refer to several actual URLs.
 * That's because group statistics aggregate statistics for all URLs that have
 * them as parent. See the superclass for the definitions of each aggregated attribute.
 * 
 * This class follows the data value object pattern. This class only defines
 * the name attributes and a getter. The superclass defines the rest. This
 * class will be used to transfer data between the persistence layer, business logic
 * and the user.
 */
public class GroupStatistics extends CommonStatistics {

    /**
     * The name of the group.
     * 
     * Set in the constructor.
     */
    private String name = null;
    
    /**
     * Constructor. Called by the persistence layer when returning statistics to
     * the business logic layer. The business logic layer creates instances also
     * in the query methods.
     * 
     * - calls the super constructor
     * - sets the name attribute
     *
     * @param name the name of the group
     * @param visitCount the visit count
     * @param lastVisit the last visit
     * @param personalRating the personal rating 
     * 
     * @throws NullPointerException if the Date or the name are null  
     */
    protected GroupStatistics(String name, int visitCount, Date lastVisit, int personalRating) throws NullPointerException {
        super(visitCount, lastVisit, personalRating);
    }
    
    /**
     * Getter for the name field.
     *
     * @return returns the value of name field
     */
    public String getName() {
        return name;
    }
        
}
