package com.topcoder.web.urlhistory.data;

import java.util.Date;

/**
 * The URLStatistics class is used to return to the user statistical information
 * about URLs.
 * 
 * URL statistics store the URL text, visit count, last visit and personal rating.
 * Note that URL statistics may refer to several actual URLs.
 * URL statistics may aggregate several URLs, because of the query / sort based on 
 * comparators requirement. See the superclass for the definitions of each attribute,
 * including aggregation explanation.
 * 
 * This class follows the data value object pattern. This class only defines
 * the URL attribute and getter. The superclass defines the rest. This
 * class will be used to transfer data between the persistence layer, business logic
 * and the user.
 */
public class URLStatistics extends CommonStatistics {
    
    /**
     * The URL text.
     * For non-aggregated URLs this is the actual URL text.
     * For aggregated URLs this is the common part. See the documentation
     * of the CompareStrategy implementations for exact definition of the
     * common part or several URLs. 
     * 
     * Set in the constructor.
     */
    private String url = null;
        
    /**
     * Constructor. Called by the persistence layer when returning statistics to
     * the business logic layer. The business logic layer creates instances also
     * in the query methods.
     * 
     * - calls the super constructor
     * - sets the url attribute
     *
     * @param url the URL of the group
     * @param visitCount the visit count
     * @param lastVisit the last visit
     * @param personalRating the personal rating 
     * 
     * @throws NullPointerException if the Date or the URL are null
     * @throws IllegalArgumentException if the groups set contains something else 
     * that Strings (including nulls)
     */
    protected URLStatistics(String url, int visitCount, Date lastVisit, int personalRating) throws NullPointerException, IllegalArgumentException {
        super(visitCount, lastVisit, personalRating);
    }
    
    /**
     * Getter for the url field.
     *
     * @return returns the value of url field
     */
    public String getURL() {
        return url;
    }
        
}
