package com.topcoder.web.urlhistory.sort;

import java.util.Comparator;
import java.util.List;

/**
 * This is a special type of comparator that aggregates more sorting comparators.
 * This is useful if we want to sort by multiple criteria. When two objects are
 * equal according to the first criteria, the second criteria is used to break
 * the tie, then the third if it is the case, and so on. 
 */
public class MultipleCriteriaSort implements Comparator {
    
    /**
     * The comparator list, according to the multiple criteria. The first
     * comparator corresponds to the first sorting criteria and so on. 
     * 
     * Set in the constructor.
     */
    private List comparators = null;
    
    /**
     * Constructor.
     *
     * @param comparators the wrapped comparator
     * 
     * @throws NullPointerException if the argument is null
     * @throws IllegalArgumentException if the List contains something else than
     * Comparator instances (or nulls) or if the size of the List is less than 2
     */
    public MultipleCriteriaSort(List comparators) throws NullPointerException, IllegalArgumentException {        
    }

    /**
     * Compares the two objects using the multiple criterias.
     * 
     * - the List is iterated and each Comparator is called on the two objects
     * - if a result different that 0 is returned, that is the final result and
     * the iteration is broken
     * - if all compators return 0, the final result is 0
     * 
     * @param o1 the first object
     * @param o2 the second object
     * 
     * @return a negative integer, zero, or a positive integer as the
     * first argument is less than, equal to, or greater than the second,
     * according to the process described above 
     */
    public int compare(Object o1, Object o2) {
        return 0;
    }

}
